==> react-native-scanbot-sdk-6.2.1.tgz: package/android/src/main/java/io/scanbot/sdk/reactnative/components/document_scanner_view/ScanbotDocumentScannerViewManager.kt <==
package io.scanbot.sdk.reactnative.components.document_scanner_view

import com.facebook.react.bridge.ReadableArray
import com.facebook.react.bridge.ReadableMap
import com.facebook.react.common.MapBuilder
import com.facebook.react.module.annotations.ReactModule
import com.facebook.react.uimanager.SimpleViewManager
import com.facebook.react.uimanager.ThemedReactContext
import com.facebook.react.uimanager.ViewManagerDelegate
import com.facebook.react.uimanager.annotations.ReactProp
import com.facebook.react.viewmanagers.ScanbotDocumentScannerViewManagerDelegate
import com.facebook.react.viewmanagers.ScanbotDocumentScannerViewManagerInterface
import io.scanbot.sdk.AspectRatio
import io.scanbot.sdk.camera.CameraModule
import io.scanbot.sdk.camera.CameraPreviewMode
import io.scanbot.sdk.reactnative.extensions.toJSON
import io.scanbot.sdk.reactnative.extensions.toJSONArray
import io.scanbot.sdk.reactnative.extensions.toPx
import io.scanbot.sdk.reactnative.models.DocumentFinderViewDefaultConfiguration
import io.scanbot.sdk.reactnative.models.DocumentPolygonDefaultConfiguration
import io.scanbot.sdk_wrapper.SBWrapper

@ReactModule(name = ScanbotDocumentScannerViewManager.NAME)
class ScanbotDocumentScannerViewManager : SimpleViewManager<ScanbotDocumentScannerView>(),
    ScanbotDocumentScannerViewManagerInterface<ScanbotDocumentScannerView> {

    private val mDelegate: ViewManagerDelegate<ScanbotDocumentScannerView> =
        ScanbotDocumentScannerViewManagerDelegate(this)

    override fun getDelegate(): ViewManagerDelegate<ScanbotDocumentScannerView>? {
        return mDelegate
    }

    companion object {
        const val NAME = "ScanbotDocumentScannerView"
    }

    override fun getName(): String {
        return NAME
    }

    override fun createViewInstance(context: ThemedReactContext): ScanbotDocumentScannerView {
        return ScanbotDocumentScannerView(context)
    }

    @Suppress("DEPRECATION")
    override fun getExportedCustomDirectEventTypeConstants(): MutableMap<String, Any>? {
        return MapBuilder.of(
            DocumentScannerResultEvent.NAME,
            MapBuilder.of("registrationName", "onDocumentScannerResult"),
            DocumentScannerDetectionResultEvent.NAME,
            MapBuilder.of("registrationName", "onDetectionResult")
        )
    }

    override fun onDropViewInstance(view: ScanbotDocumentScannerView) {
        view.removeAttachedListeners()
        super.onDropViewInstance(view)
    }

    //region Commands

    override fun freezeCamera(view: ScanbotDocumentScannerView) {
        view.documentScanner.viewController.stopPreview()
    }

    override fun unfreezeCamera(view: ScanbotDocumentScannerView) {
        view.documentScanner.viewController.startPreview()
    }

    override fun snapDocument(view: ScanbotDocumentScannerView) {
        view.documentScanner.viewController.takePicture(true)
    }

    override fun receiveCommand(
        root: ScanbotDocumentScannerView,
        commandId: String?,
        args: ReadableArray?
    ) {
        when(commandId){
            "freezeCamera" -> freezeCamera(root)
            "unfreezeCamera" -> unfreezeCamera(root)
            "snapDocument" -> snapDocument(root)
            else -> throw Error("Unrecognized command $commandId")
        }
    }

    //endregion
    //region Props
    @ReactProp(name = "acceptedAngleScore")
    override fun setAcceptedAngleScore(view: ScanbotDocumentScannerView, value: Double) {
        view.documentScanner.viewController.setAcceptedAngleScore(value)
    }

    @ReactProp(name = "acceptedBrightnessThreshold")
    override fun setAcceptedBrightnessThreshold(view: ScanbotDocumentScannerView, value: Double) {
        view.documentScanner.viewController.setAcceptedBrightnessThreshold(value)
    }

    @ReactProp(name = "acceptedSizeScore")
    override fun setAcceptedSizeScore(view: ScanbotDocumentScannerView, value: Double) {
        view.documentScanner.viewController.setAcceptedSizeScore(value)
    }

    @ReactProp(name = "autoSnappingEnabled")
    override fun setAutoSnappingEnabled(view: ScanbotDocumentScannerView, value: Boolean) {
        view.documentScanner.viewController.autoSnappingEnabled = value
    }

    @ReactProp(name = "autoSnappingSensitivity")
    override fun setAutoSnappingSensitivity(view: ScanbotDocumentScannerView, value: Double) {
        view.documentScanner.viewController.setAutoSnappingSensitivity(value.toFloat())
    }

    @ReactProp(name = "autoSnappingDelay")
    override fun setAutoSnappingDelay(view: ScanbotDocumentScannerView, value: Double) {
        // iOS only
    }

    @ReactProp(name = "cameraModule")
    override fun setCameraModule(view: ScanbotDocumentScannerView, value: String?) {
        view.documentScanner.cameraConfiguration.setCameraModule(
            CameraModule.valueOf(value!!)
        )
        view.documentScanner.viewController.restartPreview()
    }

    @ReactProp(name = "cameraPreviewMode")
    override fun setCameraPreviewMode(view: ScanbotDocumentScannerView, value: String?) {
        view.documentScanner.cameraConfiguration.setCameraPreviewMode(
            CameraPreviewMode.valueOf(value!!)
        )
    }

    @ReactProp(name = "flashEnabled")
    override fun setFlashEnabled(view: ScanbotDocumentScannerView, value: Boolean) {
        view.documentScanner.viewController.useFlash(value)
    }

    @ReactProp(name = "ignoreBadAspectRatio")
    override fun setIgnoreBadAspectRatio(view: ScanbotDocumentScannerView, value: Boolean) {
        view.documentScanner.viewController.setIgnoreBadAspectRatio(value)
    }

    @ReactProp(name = "photoQualityPrioritization")
    override fun setPhotoQualityPrioritization(view: ScanbotDocumentScannerView, value: String?) {
        view.documentScanner.cameraConfiguration.setForceMaxSnappingQuality(value === "SPEED")
    }

    @ReactProp(name = "touchToFocusEnabled")
    override fun setTouchToFocusEnabled(view: ScanbotDocumentScannerView, value: Boolean) {
        view.documentScanner.cameraConfiguration.setAutoFocusOnTouch(value)
    }

    @ReactProp(name = "requiredAspectRatios")
    override fun setRequiredAspectRatios(view: ScanbotDocumentScannerView, value: ReadableArray?) {
        val aspectRatios = value?.let {
            SBWrapper.gson.fromJson(
                it.toJSONArray().toString(),
                Array<AspectRatio>::class.java
            ).toList()
        }

        view.documentScanner.viewController.setRequiredAspectRatios(aspectRatios)
    }

    @ReactProp(name = "finderEnabled")
    override fun setFinderEnabled(view: ScanbotDocumentScannerView, value: Boolean) {
        view.documentScanner.finderViewController.setFinderEnabled(value)
    }

    @ReactProp(name = "finderLineColor", customType = "Color")
    override fun setFinderLineColor(view: ScanbotDocumentScannerView, value: Int?) {
        val color = value ?: DocumentFinderViewDefaultConfiguration.DEFAULT_FINDER_LINE_COLOR
        view.documentScanner.finderViewController.setStrokeColor(color)
    }

    @ReactProp(name = "finderLineWidth")
    override fun setFinderLineWidth(view: ScanbotDocumentScannerView, value: Double) {
        view.documentScanner.finderViewController.setStrokeWidth(value.toPx(view.resources))
    }

    @ReactProp(name = "finderOverlayColor", customType = "Color")
    override fun setFinderOverlayColor(view: ScanbotDocumentScannerView, value: Int?) {
        val color = value ?: DocumentFinderViewDefaultConfiguration.DEFAULT_OVERLAY_COLOR
        view.documentScanner.finderViewController.setOverlayColor(color)
    }

    @ReactProp(name = "finderCornerRadius")
    override fun setFinderCornerRadius(view: ScanbotDocumentScannerView, value: Double) {
        // iOS only
    }

    @ReactProp(name = "finderMinimumPadding")
    override fun setFinderMinimumPadding(view: ScanbotDocumentScannerView, value: Double) {
        view.documentScanner.finderViewController.setFinderMinPadding(value.toPx(view.resources))
    }

    @ReactProp(name = "finderAspectRatio")
    override fun setFinderAspectRatio(view: ScanbotDocumentScannerView, value: ReadableMap?) {
        val aspectRatios = if (value != null) {
            listOf(
                SBWrapper.gson.fromJson(
                    value.toJSON().toString(),
                    AspectRatio::class.java
                )
            )
        } else {
            DocumentFinderViewDefaultConfiguration.DEFAULT_ASPECT_RATIO
        }

        view.documentScanner.finderViewController.setRequiredAspectRatios(aspectRatios)
    }

    @ReactProp(name = "polygonEnabled")
    override fun setPolygonEnabled(view: ScanbotDocumentScannerView, value: Boolean) {
        view.documentScanner.polygonConfiguration.setPolygonViewVisible(value)
    }

    @ReactProp(name = "polygonBackgroundColor", customType = "Color")
    override fun setPolygonBackgroundColor(view: ScanbotDocumentScannerView, value: Int?) {
        val color = value ?: DocumentPolygonDefaultConfiguration.DEFAULT_POLYGON_BACKGROUND_COLOR
        view.documentScanner.polygonConfiguration.setPolygonFillColor(color)
    }

    @ReactProp(name = "polygonBackgroundColorOK", customType = "Color")
    override fun setPolygonBackgroundColorOK(view: ScanbotDocumentScannerView, value: Int?) {
        val color = value ?: DocumentPolygonDefaultConfiguration.DEFAULT_POLYGON_BACKGROUND_COLOR_OK
        view.documentScanner.polygonConfiguration.setPolygonFillColorOK(color)
    }

    @ReactProp(name = "polygonColor", customType = "Color")
    override fun setPolygonColor(view: ScanbotDocumentScannerView, value: Int?) {
        val color = value ?: DocumentPolygonDefaultConfiguration.DEFAULT_POLYGON_COLOR
        view.documentScanner.polygonConfiguration.setPolygonStrokeColor(color)
    }

    @ReactProp(name = "polygonColorOK", customType = "Color")
    override fun setPolygonColorOK(view: ScanbotDocumentScannerView, value: Int?) {
        val color = value ?: DocumentPolygonDefaultConfiguration.DEFAULT_POLYGON_COLOR_OK
        view.documentScanner.polygonConfiguration.setPolygonStrokeColorOK(color)
    }

    @ReactProp(name = "polygonLineWidth")
    override fun setPolygonLineWidth(view: ScanbotDocumentScannerView, value: Double) {
        view.documentScanner.polygonConfiguration.setPolygonStrokeWidth(value.toPx(view.resources))
    }

    @ReactProp(name = "polygonCornerRadius")
    override fun setPolygonCornerRadius(view: ScanbotDocumentScannerView, value: Double) {
        view.documentScanner.polygonConfiguration.setPolygonCornerRadius(value.toPx(view.resources))
    }

    @ReactProp(name = "polygonAutoSnapProgressColor", customType = "Color")
    override fun setPolygonAutoSnapProgressColor(
        view: ScanbotDocumentScannerView,
        value: Int?
    ) {
        val color = value ?: DocumentPolygonDefaultConfiguration.DEFAULT_POLYGON_AUTO_SNAP_COLOR
        view.documentScanner.polygonConfiguration.setPolygonAutoSnappingProgressStrokeColor(color)
    }

    @ReactProp(name = "polygonAutoSnapProgressLineWidth")
    override fun setPolygonAutoSnapProgressLineWidth(
        view: ScanbotDocumentScannerView,
        value: Double
    ) {
        view.documentScanner.polygonConfiguration.setPolygonAutoSnappingProgressStrokeWidth(value.toPx(view.resources))
    }

    @ReactProp(name = "polygonAutoSnapProgressEnabled")
    override fun setPolygonAutoSnapProgressEnabled(
        view: ScanbotDocumentScannerView,
        value: Boolean
    ) {
        view.documentScanner.polygonConfiguration.setPolygonAutoSnapProgressEnabled(value)
    }

    //endregion
}

==> react-native-scanbot-sdk-7.0.0.tgz: package/android/src/main/java/io/scanbot/sdk/reactnative/components/document_scanner_view/ScanbotDocumentScannerViewManager.kt <==
package io.scanbot.sdk.reactnative.components.document_scanner_view

import com.facebook.react.bridge.ReadableArray
import com.facebook.react.bridge.ReadableMap
import com.facebook.react.common.MapBuilder
import com.facebook.react.module.annotations.ReactModule
import com.facebook.react.uimanager.SimpleViewManager
import com.facebook.react.uimanager.ThemedReactContext
import com.facebook.react.uimanager.ViewManagerDelegate
import com.facebook.react.uimanager.annotations.ReactProp
import com.facebook.react.viewmanagers.ScanbotDocumentScannerViewManagerDelegate
import com.facebook.react.viewmanagers.ScanbotDocumentScannerViewManagerInterface
import io.scanbot.sdk.camera.CameraModule
import io.scanbot.sdk.camera.CameraPreviewMode
import io.scanbot.sdk.common.AspectRatio
import io.scanbot.sdk.reactnative.extensions.toJSON
import io.scanbot.sdk.reactnative.extensions.toJSONArray
import io.scanbot.sdk.reactnative.extensions.toPx
import io.scanbot.sdk.reactnative.models.DocumentFinderViewDefaultConfiguration
import io.scanbot.sdk.reactnative.models.DocumentPolygonDefaultConfiguration
import io.scanbot.sdk_wrapper.SBWrapper

@ReactModule(name = ScanbotDocumentScannerViewManager.NAME)
class ScanbotDocumentScannerViewManager : SimpleViewManager<ScanbotDocumentScannerView>(),
    ScanbotDocumentScannerViewManagerInterface<ScanbotDocumentScannerView> {

    private val mDelegate: ViewManagerDelegate<ScanbotDocumentScannerView> =
        ScanbotDocumentScannerViewManagerDelegate(this)

    override fun getDelegate(): ViewManagerDelegate<ScanbotDocumentScannerView>? {
        return mDelegate
    }

    companion object {
        const val NAME = "ScanbotDocumentScannerView"
    }

    override fun getName(): String {
        return NAME
    }

    override fun createViewInstance(context: ThemedReactContext): ScanbotDocumentScannerView {
        return ScanbotDocumentScannerView(context)
    }

    @Suppress("DEPRECATION")
    override fun getExportedCustomDirectEventTypeConstants(): MutableMap<String, Any>? {
        return MapBuilder.of(
            DocumentScannerResultEvent.NAME,
            MapBuilder.of("registrationName", "onDocumentScannerResult"),
            DocumentScannerDetectionResultEvent.NAME,
            MapBuilder.of("registrationName", "onDetectionResult")
        )
    }

    override fun onDropViewInstance(view: ScanbotDocumentScannerView) {
        view.removeAttachedListeners()
        super.onDropViewInstance(view)
    }

    //region Commands

    override fun freezeCamera(view: ScanbotDocumentScannerView) {
        view.scannerView.viewController.stopPreview()
    }

    override fun unfreezeCamera(view: ScanbotDocumentScannerView) {
        view.scannerView.viewController.startPreview()
    }

    override fun snapDocument(view: ScanbotDocumentScannerView) {
        view.scannerView.viewController.takePicture(true)
    }

    override fun receiveCommand(
        root: ScanbotDocumentScannerView,
        commandId: String?,
        args: ReadableArray?
    ) {
        when (commandId) {
            "freezeCamera" -> freezeCamera(root)
            "unfreezeCamera" -> unfreezeCamera(root)
            "snapDocument" -> snapDocument(root)
            else -> throw Error("Unrecognized command $commandId")
        }
    }

    //endregion
    //region Props
    @ReactProp(name = "acceptedAngleScore")
    override fun setAcceptedAngleScore(view: ScanbotDocumentScannerView, value: Double) {
        view.scannerView.viewController.setAcceptedAngleScore(value)
    }

    @ReactProp(name = "acceptedBrightnessThreshold")
    override fun setAcceptedBrightnessThreshold(view: ScanbotDocumentScannerView, value: Double) {
        view.scannerView.viewController.setAcceptedBrightnessThreshold(value)
    }

    @ReactProp(name = "acceptedSizeScore")
    override fun setAcceptedSizeScore(view: ScanbotDocumentScannerView, value: Double) {
        view.scannerView.viewController.setAcceptedSizeScore(value)
    }

    @ReactProp(name = "autoSnappingEnabled")
    override fun setAutoSnappingEnabled(view: ScanbotDocumentScannerView, value: Boolean) {
        view.scannerView.viewController.autoSnappingEnabled = value
    }

    @ReactProp(name = "autoSnappingSensitivity")
    override fun setAutoSnappingSensitivity(view: ScanbotDocumentScannerView, value: Double) {
        view.scannerView.viewController.setAutoSnappingSensitivity(value.toFloat())
    }

    @ReactProp(name = "autoSnappingDelay")
    override fun setAutoSnappingDelay(view: ScanbotDocumentScannerView, value: Double) {
        // iOS only
    }

    @ReactProp(name = "cameraModule")
    override fun setCameraModule(view: ScanbotDocumentScannerView, value: String?) {
        view.scannerView.cameraConfiguration.setCameraModule(
            CameraModule.valueOf(value!!)
        )
        view.scannerView.viewController.restartPreview()
    }

    @ReactProp(name = "cameraPreviewMode")
    override fun setCameraPreviewMode(view: ScanbotDocumentScannerView, value: String?) {
        view.scannerView.cameraConfiguration.setCameraPreviewMode(
            CameraPreviewMode.valueOf(value!!)
        )
    }

    @ReactProp(name = "flashEnabled")
    override fun setFlashEnabled(view: ScanbotDocumentScannerView, value: Boolean) {
        view.scannerView.viewController.useFlash(value)
    }

    @ReactProp(name = "ignoreOrientationMismatch")
    override fun setIgnoreOrientationMismatch(view: ScanbotDocumentScannerView, value: Boolean) {
        view.scannerView.viewController.setIgnoreOrientationMismatch(value)
    }

    @ReactProp(name = "photoQualityPrioritization")
    override fun setPhotoQualityPrioritization(view: ScanbotDocumentScannerView, value: String?) {
        view.scannerView.cameraConfiguration.setForceMaxSnappingQuality(value === "SPEED")
    }

    @ReactProp(name = "touchToFocusEnabled")
    override fun setTouchToFocusEnabled(view: ScanbotDocumentScannerView, value: Boolean) {
        view.scannerView.cameraConfiguration.setAutoFocusOnTouch(value)
    }

    @ReactProp(name = "requiredAspectRatios")
    override fun setRequiredAspectRatios(view: ScanbotDocumentScannerView, value: ReadableArray?) {
        val aspectRatios = value?.let {
            SBWrapper.gson.fromJson(
                it.toJSONArray().toString(),
                Array<AspectRatio>::class.java
            ).toList()
        }

        view.scannerView.viewController.setRequiredAspectRatios(aspectRatios)
    }

    @ReactProp(name = "finderEnabled")
    override fun setFinderEnabled(view: ScanbotDocumentScannerView, value: Boolean) {
        view.scannerView.finderViewController.setFinderEnabled(value)
    }

    @ReactProp(name = "finderLineColor", customType = "Color")
    override fun setFinderLineColor(view: ScanbotDocumentScannerView, value: Int?) {
        val color = value ?: DocumentFinderViewDefaultConfiguration.DEFAULT_FINDER_LINE_COLOR
        view.scannerView.finderViewController.setStrokeColor(color)
    }

    @ReactProp(name = "finderLineWidth")
    override fun setFinderLineWidth(view: ScanbotDocumentScannerView, value: Double) {
        view.scannerView.finderViewController.setStrokeWidth(value.toPx(view.resources))
    }

    @ReactProp(name = "finderOverlayColor", customType = "Color")
    override fun setFinderOverlayColor(view: ScanbotDocumentScannerView, value: Int?) {
        val color = value ?: DocumentFinderViewDefaultConfiguration.DEFAULT_OVERLAY_COLOR
        view.scannerView.finderViewController.setOverlayColor(color)
    }

    @ReactProp(name = "finderCornerRadius")
    override fun setFinderCornerRadius(view: ScanbotDocumentScannerView, value: Double) {
        // iOS only
    }

    @ReactProp(name = "finderMinimumPadding")
    override fun setFinderMinimumPadding(view: ScanbotDocumentScannerView, value: Double) {
        view.scannerView.finderViewController.setFinderMinPadding(value.toPx(view.resources))
    }

    @ReactProp(name = "finderAspectRatio")
    override fun setFinderAspectRatio(view: ScanbotDocumentScannerView, value: ReadableMap?) {
        val aspectRatios = if (value != null) {
            listOf(
                SBWrapper.gson.fromJson(
                    value.toJSON().toString(),
                    AspectRatio::class.java
                )
            )
        } else {
            DocumentFinderViewDefaultConfiguration.DEFAULT_ASPECT_RATIO
        }

        view.scannerView.finderViewController.setRequiredAspectRatios(aspectRatios)
    }

    @ReactProp(name = "polygonEnabled")
    override fun setPolygonEnabled(view: ScanbotDocumentScannerView, value: Boolean) {
        view.scannerView.polygonConfiguration.setPolygonViewVisible(value)
    }

    @ReactProp(name = "polygonBackgroundColor", customType = "Color")
    override fun setPolygonBackgroundColor(view: ScanbotDocumentScannerView, value: Int?) {
        val color = value ?: DocumentPolygonDefaultConfiguration.DEFAULT_POLYGON_BACKGROUND_COLOR
        view.scannerView.polygonConfiguration.setPolygonFillColor(color)
    }

    @ReactProp(name = "polygonBackgroundColorOK", customType = "Color")
    override fun setPolygonBackgroundColorOK(view: ScanbotDocumentScannerView, value: Int?) {
        val color = value ?: DocumentPolygonDefaultConfiguration.DEFAULT_POLYGON_BACKGROUND_COLOR_OK
        view.scannerView.polygonConfiguration.setPolygonFillColorOK(color)
    }

    @ReactProp(name = "polygonColor", customType = "Color")
    override fun setPolygonColor(view: ScanbotDocumentScannerView, value: Int?) {
        val color = value ?: DocumentPolygonDefaultConfiguration.DEFAULT_POLYGON_COLOR
        view.scannerView.polygonConfiguration.setPolygonStrokeColor(color)
    }

    @ReactProp(name = "polygonColorOK", customType = "Color")
    override fun setPolygonColorOK(view: ScanbotDocumentScannerView, value: Int?) {
        val color = value ?: DocumentPolygonDefaultConfiguration.DEFAULT_POLYGON_COLOR_OK
        view.scannerView.polygonConfiguration.setPolygonStrokeColorOK(color)
    }

    @ReactProp(name = "polygonLineWidth")
    override fun setPolygonLineWidth(view: ScanbotDocumentScannerView, value: Double) {
        view.scannerView.polygonConfiguration.setPolygonStrokeWidth(value.toPx(view.resources))
    }

    @ReactProp(name = "polygonCornerRadius")
    override fun setPolygonCornerRadius(view: ScanbotDocumentScannerView, value: Double) {
        view.scannerView.polygonConfiguration.setPolygonCornerRadius(value.toPx(view.resources))
    }

    @ReactProp(name = "polygonAutoSnapProgressColor", customType = "Color")
    override fun setPolygonAutoSnapProgressColor(
        view: ScanbotDocumentScannerView,
        value: Int?
    ) {
        val color = value ?: DocumentPolygonDefaultConfiguration.DEFAULT_POLYGON_AUTO_SNAP_COLOR
        view.scannerView.polygonConfiguration.setPolygonAutoSnappingProgressStrokeColor(color)
    }

    @ReactProp(name = "polygonAutoSnapProgressLineWidth")
    override fun setPolygonAutoSnapProgressLineWidth(
        view: ScanbotDocumentScannerView,
        value: Double
    ) {
        view.scannerView.polygonConfiguration.setPolygonAutoSnappingProgressStrokeWidth(
            value.toPx(
                view.resources
            )
        )
    }

    @ReactProp(name = "polygonAutoSnapProgressEnabled")
    override fun setPolygonAutoSnapProgressEnabled(
        view: ScanbotDocumentScannerView,
        value: Boolean
    ) {
        view.scannerView.polygonConfiguration.setPolygonAutoSnapProgressEnabled(value)
    }

    @ReactProp(name = "hardwareButtonsEnabled")
    override fun setHardwareButtonsEnabled(view: ScanbotDocumentScannerView?, value: Boolean) {
        // iOS only
    }

    //endregion
}
